==> react-filter-utils-0.0.13.tgz: package/es/index.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { isPlainObject } from './utils';

function createFilter(map, valueMap, options = {}) {
  const list = Object.keys(map).map((value, index) => {
    let label = map[value];
    const rest = {};

    if (label && isPlainObject(label)) {
      const labelObj = label;
      Object.keys(labelObj).forEach(key => {
        if (key === 'label') label = labelObj[key];else rest[key] = labelObj[key];
      });
    }

    const item = _objectSpread({
      value,
      label: label
    }, rest);

    const isContinue = options.onWalkListItem && options.onWalkListItem(item, index);
    if (isContinue === false) return;
    return isPlainObject(isContinue) ? isContinue : item;
  }).filter(Boolean);

  const createList = function (values) {
    return list.filter(v => !values || values.includes(v.value));
  };

  const filter = options.filter || function (value) {
    let label = map[value];
    if (!label) return '';
    return typeof label === 'object' ? label.label : label;
  };

  filter.list = list;
  filter.createList = createList;
  filter.map = map;

  if (!valueMap) {
    valueMap = Object.keys(map).reduce((p, key) => {
      if (key) p[key] = key;
      return p;
    }, {});
  }

  Object.keys(valueMap).forEach(key => {
    if (!key) return;
    filter[key] = valueMap[key];
  });
  let external = options.external;

  if (external) {
    if (typeof external === 'function') external = external.call(filter, filter);
    external && Object.assign(filter, external);
  }

  return filter;
}

export { createFilter };

==> react-filter-utils-0.0.14.tgz: package/es/index.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { isPlainObject } from './utils';

function createFilter(map, valueMap, options = {}) {
  const filter = options.filter || function (value, defaultLabel = '') {
    let label = map[value];
    if (!label) return defaultLabel;
    return typeof label === 'object' ? label.label || defaultLabel : label;
  };

  filter.map = map;
  const list = Object.keys(map).map((value, index) => {
    let label = filter.map[value];
    const rest = {};

    if (label && isPlainObject(label)) {
      const labelObj = label;
      Object.keys(labelObj).forEach(key => {
        if (key === 'label') label = labelObj[key];else rest[key] = labelObj[key];
      });
    }

    const item = _objectSpread({
      value,
      label: label
    }, rest);

    const isContinue = options.onWalkListItem && options.onWalkListItem(item, index);
    if (isContinue === false) return;
    return isPlainObject(isContinue) ? isContinue : item;
  }).filter(Boolean);
  filter.list = list;

  const createList = function (values) {
    return filter.list.filter(v => !values || values.includes(v.value));
  };

  filter.createList = createList;

  if (!valueMap) {
    valueMap = Object.keys(map).reduce((p, key) => {
      if (key) p[key] = key;
      return p;
    }, {});
  }

  Object.keys(valueMap).forEach(key => {
    if (!key) return;
    const d = Object.getOwnPropertyDescriptor(valueMap, key);
    if (d) Object.defineProperty(filter, key, d);
  });
  let external = options.external;

  if (external) {
    if (typeof external === 'function') external = external.call(filter, filter);

    if (external) {
      Object.getOwnPropertyNames(external).forEach(key => {
        const d = Object.getOwnPropertyDescriptor(external, key);
        d && Object.defineProperty(filter, key, d);
      });
    }
  }

  return filter;
}

export { createFilter };
